@@ -1,6 +1,6 @@
 import sys
 # from Raster import Raster
-from raster import Raster
+from .raster import Raster
 import ogr
 import os
 import gdal
