@@ -9,11 +9,8 @@ cord=(116.5, 39.9, 116.6, 39.8, 14)
 class_key='building'
 datasource="Google China"
 DataSetName="BuildingDataSet"
-import sys
-sys.path.append("/workspace/DARTH/Darth")
-print(sys.path)
-from process import Process
 
+from Darth.process import Process
 
 Process(
     vector,
